function [xx,yy]=EE(f,x0,y0,xn,h)
% function [xx,yy]=EE(f,x0,y0,xn,h)
% Explicit Euler method for equation y'=f(x,y)
%        f - anonymous function
% y(x0)=y0 - initial condition
%       xn - right boundary point of the interval
%        h - step
%    xx,yy - knots and approximation solution

x=x0;
y=y0;
xx=x0;
yy=y0;
while x<xn
    y=y+h*f(x,y);
    x=x+h;
    xx=[xx,x];
    yy=[yy,y];
end

end % end of function EE